%	====================================================
%			       astaCade 
%	====================================================
%  	Visualizza il moto di un'asta che ha un estremo A vincolato ad un  
%     asse orizzontale liscio e nr mostra la reazione verticale  (Q) in A
%	baricentro G
%	Coordinate: xG e ad angolo "theta"  (a) con l'orizzontale.
%	Equazioni usate:  le due componenti della prima eq. cardinale:  
%	   							Rx + R'x=0       Ry + R'y=0
%	La prima componente porta a 	xG = costante
%	la seconda porta a:				m*y''G = Q -  m*g
%	La seconda equazione cardinale con polo nel baricentro G
%	porta a:						(m*L*L/12)*a''= - Q*L/2*cos(a)
%	Combinando la seconda e la terza equazione si ottiene il sistema dinamico
%		a' = w
%		w' =  - 1/2*cos(a) * (g - L/2*sin(a)*w*w) / (L/12+L/4*cos(a)*cos(a));
%	Metodo di integrazione di Runge-Kutta del IV ordine
%	----------modalita' grafica--------------
	close ; h1 = figure(1) ; 	
	set(h1, 'Units', 'normalized', 'Position', [0  0  1  1]) ; 
%	set(h1, 'Units', 'normalized', 'Position', [0.5  0.5  0.5  0.5]) ; 
	 	whitebg(h1, 'black')
hold on ;  pause on ;  zoom on
	axis equal ;    axis([-6  6  -4  6]);
% 	 ---------------------  Dati  ----------------------------
	L = 3;		% lunghezza asta in metri
	m = 1;		% massa dell'asta (kg)
	n = 10;		% numero fotogrammi 
	p = 2 * pi / n;	% passo angolare in radianti
	c = 1.2*L;		% lunghezza assi in metri
	g = 9.81; 		% accelerazione di gravit in metri al secondo quadro
	tf = 30;		% tempo finale in secondi (valore fasullo)
	xG = 0;		% ascissa iniziale del baricentro
	fs =  0.05; 		% fattore di scala per le forze
%  	 ------------------Traccia ------------------------------ 
	f_vettoreX(-3, 0, 6, 'c',1,    0.32, 0.20  ) ;  % asse orizzontale
	f_vettoreY(0, -3.5, 7, 'c',1,    0.32, 0.20  ) ;  % asse verticale
%
% 	usando il "while" si evita la formazione di un array	
	a0 = 60*pi/180;	% angolo di partenza in gradi convertito in radianti
	w0 = 0; 			% velocit angolare iniziale	
	dt = 0.02;	 t=0; 	a=a0;	w=w0;
	while  w <= 0    % prosegue fino a quando l'asta ruota in senso orario
%		
%		[da , dw] = f_asta(t, a, w, L, g,  dt); % metodo di Eulero attualmente congelato
%
%		metodo d'integrazione di Runge-Kutta del IV ordine
		[h1 , k1] = f_asta(t, a, w, L, g,  dt);
		[h2,  k2] = f_asta(t + dt/2 , a+h1/2 ,  w + k1/2, L, g,  dt);
		[h3,  k3] = f_asta(t + dt/2 , a+h2/2 ,  w + k2/2,L, g,   dt);
 		[h4,  k4] = f_asta(t + dt    , a+h3  ,     w + k3, L, g,  dt);
		da  = (h1+2*h2+2*h3+h4) / 6; 
		dw = (k1+2*k2+2*k3+k4) / 6; 		
		tn = t+dt; 	an = a+da; 	wn = w+dw;	% aggiorna i valori
%		traccia asta
		xA = xG - L/2*cos(a);	 xB = xG + L/2*cos(a);	 	
		yA = 0;	 yB =  L*sin(a);	
 		plot([xA  xB] , [yA  yB] , 'color' , 'y' , 'linewidth' , 1 , 'era' , 'back');
% 		traccia reazione
		Q = (m*g - m*L/2*sin(a)*w*w) / (1+3*L*cos(a)*cos(a));
 		plot([xA  xA] , [0  Q*fs] , 'color' , 'm' , 'linewidth' , 1 , 'era' , 'back');
		t = tn; 	a = an; 	w = wn;	% sostituisici ai vecchi valori i nuovi valori
%		stampa i valori di alcune variabili
		stringa=' angolo= %5.1f  ;  xA= %5.1f  ; vel angol= %5.1f rad/s ; reaz=  %5.1f N  \n';
 		fprintf(stringa,a*180/pi, xA,w,Q);
		pause
	end
%  	 ------------------------------------------------- fine 
 
