%	 BALESTRA
%	Una balestra schematizzata come un'asta che ruota attorno ad un estremo
%	sotto l'azione di una molla a spirale (tipo trappola per topi) e con un anellino
%	che tende a sfuggire. Il moto  diviso in due fasi: l'anellino che scorre sull'asta
%	e l'anellino che viene lanciato dopo essere fuioriuscito dall'asta.
%	
% 	chiama "f_balestra.m"
	
%	----------modalit grafica--------------
	close ; h1 = figure(1) ; 	
%	set(h1, 'Units', 'normalized', 'Position', [0.5 0.5 0.45 0.45]);
	set(h1, 'Units', 'normalized', 'Position', [0 0  1  0.96]);
	hold on ; axis on ; zoom on ; pause on
  	h2=title('balestra');
 	whitebg(h1, 'black')
	set(h2,'fontsize',24,'color','red','fontname','times');
	axis equal ; axis([0  2.2  -0.1  1.2]);
%	-----------------------------------------------------------
	M = 0.1;		% massa asta in kg
	m = 0.003;	% massa anellino in kg
	L =  1;		% lunghezza asta in m
	g = 9.81;		% accelerazione di gravit in m/s/s
	k =  0.08;		% Nm/rad
%	-----------------------------------------------------------
%	Le due equazioni sono:
% 		1)	la seconda  equazione cardinale con polo nella cerniera A
%		2)	equazione di moto di un punto sull'asta mobile
%	variabili: 
% 	theta (a);   rho (r);   velocit angolare (w);   velocit radiale (v) 
%	Derivate  a' (=w) ,  r' (=v) ,  a'' , r''
%	1)	1/3*ML*L *a" + 2*m*r*r'*a'+m*r*r*a"=-k*a - m*g*r*cos(a)
%	2)	m*(r"-r*a'*a') = - m*g*cos(a)
%	Metodo di integrazione di  Runge-Kutta IV ordine. 
%	Sistema dinamico:	r' = v
%						a' = w	
%						v' = f(r,a,v,w,t)
%						w' = g(r,a,v,w,t)
% 	con	f =  r*w*w - g*sin(a)
%		g = (+ k*(2*pi-a)  - m*g*r*cos(a) - 2*m*r*v*w)/(1/3 *M*L*L + m*r*r)
%	-----------------------------------------------------------
	xA = 1; yA=0; % cerniera
	plot(xA,yA,'rx','linewidth',1,'era','back')	
%	--------------integrazione  Runge-Kutta ------------------------ 		
% 	usiamo il "while" per bloccare la prima fase quando l'anellino esce dall'asta	
	t0 = 0;  r0 = L/2; a0 = 0;  v0 =  0.1 ; w0 = 0; % condizioni iniziali	
	dt = 0.09;	 t=t0;  r=r0;  a=a0; v=v0;  w=w0;
	while   r < L &  a < pi   & r>0  % il simbolo "&" sta per "and"
	 	[dr1,da1,dv1,dw1] = f_balestra(t, r, a, v, w, M, m, g , L, k, dt);
 	 	[dr2,da2,dv2,dw2] = f_balestra(t+dt/2,r+dr1/2, a+da1/2,  v+dv1/2,  w+dw1/2, M, m, g , L, k, dt);
 	 	[dr3,da3,dv3,dw3] = f_balestra(t+dt/2,r+dr2/2, a+da2/2,  v+dv2/2,  w+dw2/2, M, m, g , L, k, dt);
 	 	[dr4,da4,dv4,dw4] = f_balestra(t+dt   ,r+dr3   , a+da3   ,  v+dv3   ,  w+dw3, M, m, g , L, k, dt);
	 	dr = dt*(dr1+2*dr2+2*dr3+dr4) /6; 
	 	da = dt*(da1+2*da2+2*da3+da4) /6; 
	 	dv = dt*(dv1+2*dv2+2*dv3+dv4) /6; 
	 	dw = dt*(dw1+2*dw2+2*dw3+dw4) /6; 	
%		Eulero
%		[dr,da,dv,dw] = f_balestra(t, r, a, v, w, M, m, g , L, k, dt);
		tn = t+dt; rn = r+dr; an = a+da; vn = v+dv; wn = w+dw;
		xB = xA+L*cos(an); yB = yA+L*sin(an);
		% disegna l'asta AB
 		plot([xA  xB],[yA  yB],'color','b','linewidth',0.5,'era','back')
		% disegna l'anellino
		xP = xA+ rn*cos(an);  yP = yA+ rn*sin(an); 
		plot(xP,yP,'yo','linewidth',1,'era','back')
		t = tn; r = rn; a = an; v = vn; w = wn;
		% scrivi valori angolo e raggio
		fprintf('theta = %4.0f        rho = %5.2f  m\n', a*180/pi, r)
		pause
	end
% -------------------------------------------------------------------------- fine
%	function [dr,da,dv,dw] = f_balestra(t, r, a, v, w, M, m, g , L, k, dt);
% 	chiamata da "balestra.m"
%	 ------------------------------------------------------------------------------------	
%	dr = dt*v ;
%	da = dt* w;
%	dv = dt*( r*w*w - g*sin(a));
%		num = + k*(2*pi-a)  - m*g*r*cos(a) - 2*m*r*v*w;
%		den = 1/3 *M*L*L + m*r*r ;
%	dw = dt*num / den;
%	NB. il momento non  di richiamo ma di allontanamento!

