%	============================================================== 
%   	DIAGRAMMA DEL MOMENTO FLETTENTE DI UN PORTALE
%	============================================================== 
%	nome del programma: "flettente.m"
%	funzioni chiamate: 
%	f_cerniera, f_pallina,f_arco
%	per fare i caratteri equispaziati usato il carattere "courier"
%	-------------------------------------------------------------- 
	clear 	% azzera le variabili in memoria
	clc		% pulisci finestra di testo
	close		% chiudi finestra grafica precedente	
%	-------------------------------------------------------------- 
%				SELEZIONA LA MODALITA' GRAFICA
%	-------------------------------------------------------------- 
% 	apri una finestra grafica di dimensioni volute
	h1 = figure(1); 	
% 	set(h1, 'Units', 'normalized', 'Position', [0.5 0.5 0.45 0.5]);
	set(h1, 'Units', 'normalized', 'Position', [0 0  1  0.96]);
  	whitebg(h1, 'black') % 	colore di fondo nero
% 	colore della cornice
   set (gcf,'color','blue') % dopo "whitebg"
%	assi di dimensioni volute
 	axis([0 120 0 100] );  % [xmin xmax ymin ymax]
	axis equal
	hold on 	% consente piu' tracciamenti sulla stessa finestra
	zoom on	% consente di ingrandire un particolare
%	-------------------------------------------------------------- 
%				DATI
%	-------------------------------------------------------------- 
%	misure del portale
	h=70; 	% altezza portale
	b=40;  	% semilarghezza portale
%  fattori di scala
	fL=0.7;  % fattore di scala per le lunghezze
	fF=1;  	% fattore di scala per le forze
	fM=0.05; % fattore di scala per i momenti
%	coordinate dei punti salienti
 	A=[20  10];
	E=[A(1)   A(2)+h*fL];	
	B=[A(1)+b*fL   E(2)];	
	G=[A(1)+2*b*fL   E(2)];	
	C=[G(1)    A(2)];	
%	-------------------------------------------------------------- 
%		 		STRUTTURA 
%	-------------------------------------------------------------- 
	g(1)=line([A(1)  E(1)],[A(2)  E(2)]);
	g(2)=line([E(1)  B(1)],[E(2)  B(2)]);
	g(3)=line([B(1)  G(1)],[B(2)  G(2)]);
	g(4)=line([G(1)  C(1)],[G(2)  C(2)]);
	set(g,'linewidth',2,'color','white');
%	-------------------------------------------------------------- 
%				VINCOLI
%	-------------------------------------------------------------- 
%	cerniera in B
	f_cerniera(B(1), B(2), 1.5, 'k','w');
%	carrello in C
	X=[C(1)  C(1)+3  C(1)-3  C(1)];
	Y=[C(2)  C(2)-4  C(2)-4  C(2)];
	plot(X,Y,'w')
	f_cerniera(C(1)-2, C(2)-5.5, 1.2, 'k','w');
	f_cerniera(C(1)+2, C(2)-5.5, 1.2, 'k','w');
	f_cerniera(C(1)  , C(2)    , 1.5, 'k','w');
	XC=[C(1)-4     C(1)+4     C(1)+4  C(1)-4  C(1)-4];
	YC=[C(2)-6.8   C(2)-6.8   C(2)-8  C(2)-8  C(2)-6.8];
	fill(XC,YC,'w')
%	incastro in A
	XA=[A(1)-4  A(1)+4  A(1)+4   A(1)-4   A(1)-4];
	YA=[A(2)    A(2)    A(2)-4   A(2)-4   A(2)  ];
	fill(XA,YA,'w')
%	-------------------------------------------------------------- 
%				SCRITTE
%	-------------------------------------------------------------- 
  	text(A(1),A(2),'   A','fontsize',18,'fontname','times');
  	text(C(1),C(2),'   C','fontsize',18,'fontname','times');
  	h3=title('diagramma momenti di un portale');
  	set(h3,'fontsize',18,'color','yellow','fontname','helvetica');
%	-------------------------------------------------------------- 
%				FORZE (in verde)
%	-------------------------------------------------------------- 
	D=[B(1)+b*fL/2  B(2)];%	punto di applicazione della forza
	F=-10; % componenti della forza in newton (N)
	s(1)=line([D(1)  D(1)],[D(2)  D(2)+F*fF]);	
	f_pallina(D(1), D(2), 1,'g');
	set(s,'linewidth',2,'color','green ');
%	-------------------------------------------------------------- 
%				REAZIONI (in rosso)
%	-------------------------------------------------------------- 
	VA=F/2; 	% reazione verticale in A
	VC=F/2;	% reazione verticale in B
	MA=F*b/2;% momento di incastro in A
	e=2; 		% piccolo spostamento laterale reazioni
	r=8;		% raggio per tracciare il momento
%	reazione verticale in A
	f_pallina(A(1)+e, A(2), 1,'r');
	j(1)=line([A(1)+e  A(1)+e],[A(2)  A(2)-VA*fF]);	
%	momento di incastro in A
	f_arco(A(1), A(2), r, 180, 320, 'r')
	f_pallina(A(1)-r, A(2), 1,'r');
%	reazione verticale in C
	f_pallina(C(1)+e, C(2), 1,'r');
	j(2)=line([C(1)+e  C(1)+e],[C(2)  C(2)-VC*fF]);	
	set(j,'linewidth',2,'color','r');
%	-------------------------------------------------------------- 
%				DIAGRAMMA MOMENTO FLETTENTE (in celeste)
%	-------------------------------------------------------------- 
	p=1; % passo tra le lineette del diagramma
% 	piedritto sinistro (in salita)
	for s=0:p:h
		M=-F*b/2;
		m=line([A(1)  A(1)-M*fM],[A(2)+s*fL  A(2)+s*fL]);	
		set(m,'linewidth',1,'color','c');
	end
%	traverso:(verso destra) fino alla forza F
	for s=0:p:(3*b/2)
		M=-F*b/2+F/2*s;
		m=line([A(1)+s*fL  A(1)+s*fL],[E(2)  E(2)+M*fM]);	
		set(m,'linewidth',1,'color','c');
	end
%	traverso:(verso destra) dalla forza F fino all'estremo destro 
	for s=(3*b/2):p:(2*b)
		M=-F*b/2+F/2*s-F*(s-3*b/2);
		m=line([A(1)+s*fL  A(1)+s*fL],[E(2)  E(2)+M*fM]);	
		set(m,'linewidth',1,'color','c');
	end
%	piedritto destra (in discesa)
	for s=0:p:h
		M=0;
		m=line([C(1)  C(1)+M*fM],[E(2)-s*fL  E(2)-s*fL]);	
		set(m,'linewidth',1,'color','y');
	end
%	-------------------------- fine ------------------------------ 
	
	
