%
%  OSCILLATORE SEMPLICE SMORZATO (SDOF)
%
% Il programma si propone di risolvere l'equazione differenziale 
% di un moto oscillatorio smorzato al variare del rapporto di
% smorzamento.
%  L'equazione differenziale e':
%	m ddu + c du + k u= 0
%  w= omega csi = epsilon / omega = c/(2 m omega)
%  La soluzione generale e':
%	u(t)= u(0) exp(- w csi t) * sin(w t+alpha)
%
%  x(t) = exp(- epsilon   t) C sin(omegad t+alpha) 
%  u(t) = exp(- csi omega t) C*sin(omegad*t+alfa)
% assegnati i valori iniziali di u e di v si ottiene
%   A = (csi*omega*u0+v0)/(omegad);
%   B = u0;
% ------------------------------------------------
	clear all   %  cancella tutte le variabili in memoria  
	close all	%  chiudi tutte le finestre grafiche
%
	W = .4;		%  peso kgf
	g = 9.81;	%  accelerazione di gravit m/s^2
	m = W/g;	%  massa del sistema oscillante in kg (SI)
	c = 2.2;	%  coefficiente di smorzamento
	k = 50;     %  rigidezza
%  
%  condizioni iniziali
%   
	u0 = .02;   %  spostamento iniziale in m 
	v0 = .1;    %  velocit iniziale m/s
%  
	omega = sqrt(k/m); %  frequenza naturale del sistema
	T=2*pi/omega;    %  periodo
	csi = c/(2*m*omega);           %  rapporto di smorzamento
	omegad = omega*sqrt(1-(csi)^2);   %  frequenza smorzata (dumping)
%  
	A = (csi*omega*u0+v0)/(omegad);
	B = u0;
	C = sqrt(A^2+B^2);
	alfa = atan(B/A);

	
	p=T/10;       %  passo temporale= T/10 circa
	t=0;          %istante iniziale
  tfin=T*4;     %10 periodi


    if csi>1   %  sistemi sovrasmorzati
       d1 = A*exp(omega*t*sqrt((csi)^2-1));
       d2 = B*exp(-omega*t*sqrt((csi)^2-1));
       u = exp(-csi*omega*t).*(d1+d2);
       plot(t,u)
    end
% %  
%     if csi = 1 %  smorzamento critico
%        u(t) = (u0*(1+omega*t)+v0*t).*exp(-omega*t);
%        plot u(t)
%     end
% %

    if csi<1  %  sistemi sottosmorzati
		t=0:p:tfin; %creo l'array dei tempi
         u = exp(-csi*omega*t).*(C*sin(omegad*t+alfa));
         plot(t,u)
    end

% 




