%
%               OCCORRE RUNGE-KUTTA!
%
%========================================
%            pendolo.m
%    grandi oscillazioni del pendolo
%========================================
% Si considera un pendolo (filo+pallina)  che compie grandi oscillazioni potendo 
% anche compiere un giro completo.  Considerato l'angolo "theta" tra il 
% pendolo e la verticale si divide  l'angolo tra 0 e 2pigreco in "n" parti.
% L'angolo theta e' stato indicato con  "A(k)" mentre la velocita' angolare omega
% e' stata indicata con "Vang(k)" Richiamato lo script "linea.m"
%	----------modalit grafica--------------
	clear all
	close ; h1 = figure(1) ; 	
	set(h1, 'Units', 'normalized', 'Position', [0.5  0.5  0.5  0.5]) ; 
	hold on % indispensabile: traccia su una stessa pagina grafica
	axis equal ; axis([-0.35   0.35   -0.35   0.35]) 
%----------------------------------------
%  		dati
%----------------------------------------
	r=0.20; 		% m
	m=0.020; 	% kg
	g=9.81; 		% m/s/s
	n=1000;		% numero suddivisioni 
 	fs=0.1; 		% fattore scala forze
	h =0.001; 		% passo di integrazione (intervallo di tempo)
% valore minimo della velocita' iniziale per far compiere un giro completo.
	vc=sqrt(5*g*r); % m/s
	v0= vc+0.0; 	% m/s	
%----------------------------------------
%     processo di integrazione
%----------------------------------------
% Si noti che in MATLAB il primo indice di  una array non puo' essere zero.
 	k=1; 		% contatore passi 
	T(k)=0;		% array dei tempi
	A(k)=0;  		% angolo alfa iniziale
	Vang(k) = v0 / r; 	% vel angolare iniziale
	Tens(k) = m*r*Vang(k)^2+m*g*cos(A(k)) ;
 	X(k) =r*sin(A(k));  Y(k)=-r*cos(A(k));

% Ciclo di integrazione	
% Si inizia un ciclo che deve proseguire  fintanto che si realizzano 
% tutte le tre condizioni seguenti: 
% 1) la tensione deve essere positiva: Tens(k)>0
% 2) la velocita' angolare e' positiva: Vang(k)>0;
% 3) l'angolo inferiore a 2 pi: A(k)<2*pi.
% Si noti che per il ciclo "while" alle variabili che determinano
% l'arresto del ciclo si devono assegnare dei valori di partenza. 
%  Qui si creano gli array 
% asse "y" verso l'alto
% il simbolo "&" sta per "and"
%  non sente il WHILE! 
	while Tens(k) > 0.1 & Vang(k)>0 & A(k)<(2*pi-0.1);
		k=k+1;
		T(k) = T(k-1) + h;
		A(k) = A(k-1)+Vang(k-1) * h;
		Vang(k) = Vang(k-1) - g/r*sin(A(k-1)) * h;
% 		Eventuale arresto se la velocita' angolare  negativa
 %		if Vang(k)<0; disp(Vang(k)); end
% 		calcola la tensione del filo
		Tens(k) = m*r*Vang(k)^2 + m*g*cos(A(k));
%		e le coordinate della pallina	
 		X(k) = r*sin(A(k));  Y(k) = -r*cos(A(k));
%		disp(Tens(k))
	end		
%----------------------------------------	
% Traccia alcuni fotogrammi (ricorda "hold on") 
% altrimenti traccia solo l'ultimo fotogramma
	plot(0,0,'y*'); % pallina
	j = size(A,2);
	for k=1:6: j   % ogni 4 intervalli di integrazione
		pause
   		plot(X(k),Y(k),'bo'); % pallina
% 		traccia il filo
		plot([0  X(k)],[0  Y(k)],'g','linewidth',1);
% 		traccia il peso
		yp=Y(k)-m*g*fs;
		plot([X(k)  X(k)],[Y(k)  yp],'g','linewidth',2);
%		traccia tensione filo
 		tx=-Tens(k)*sin(A(k));  Ty=+Tens(k)*cos(A(k));
		xp=X(k)+tx*fs ; yp=Y(k)+Ty*fs;
		plot([X(k)  xp],[Y(k)  yp],'r','linewidth',2);
% 		traccia  la forza centrifuga			
  		f=m*r*Vang(k)^2;
		fx= f*sin(A(k));  fy=-f*cos(A(k));
		xp=X(k)+fx*fs ; yp=Y(k)+fy*fs;
		plot([X(k)  xp],[Y(k)  yp],'b','linewidth',3);
 	end
%%%%		plot([a  b],[c  d],'c','linewidth',1);
 	
 
