%===============================================
% funzione [X,Y,Z]=ruota3D(x,y,z,phi,theta,psi)
%  		 (fatto il 2 aprile 1997)
%-----------------------------------------------
% Siano date due terne con la medesima origine, 
% la prima indicata con (X,Y,Z)
% la seconda con (x,y,z).
% La seconda terna e' individuata mediante i tre
% angoli di Eulero "phi","theta","psi" (in GRADI)
% valutati rispetto alla prima terna.
% Ci proniamo di determinare le coordinate X,Y,Z
% di un punto date le sue coordinate x,y,z.
%
% Il processo di Eulero e' il seguente:
% inizialmente le due terne coincidono.
% Si fa prima una rotazione attorno all'asse "Z"
% di un angolo "phi" (longitudine) 
% e si arriva a (x1,y1,z1);
% 
% quindi si fa la rotazione attorno al nuovo asse
% "x1" (chiamato "asse dei nodi")
% di un angolo "theta" (colatitudine).
% e si arriva ad una seconda terna (x2,y2,z2);
%
% infine si ruota di un angolo "psi" 
% (rotazione propria) attorno al nuovo asse "z2".
% e si arriva a (x,y,z).
%
% Poiche' si parte dalle coordinate x,y,z 
% le tre trasformazioni devono essere eseguite 
% a ritroso.

	function [X,Y,Z]=ruota3D(x,y,z,phi,theta,psi)
	
% trasforma gli angoli entranti da gradi a radianti
% ATTENZIONE: dimenticarlo fa venire i sorci verdi!		
	phi    = phi  *pi/180 ;
	theta = theta *pi/180 ;
	psi    = psi  *pi/180 ;
	
% Passaggio dalla terna (x,y,z) alla terna (x2,y2,z2)
% precedente che non ha ancora subito la rotazione
% attorno all'asse "z2"		
	x2 =  x*cos(psi) - y*sin(psi);
	y2 =  x*sin(psi) + y*cos(psi);
	z2 =  z;
	
% Passaggio dalla terna (x2,y2,z2) alla terna
% precedente (x1,y1,z1) che non ha ancora subito 
% la rotazione attorno all'asse "x1"				
	x1 =  x2;
	y1 =  y2*cos(theta) - z2*sin(theta);
	z1 =  y2*sin(theta) + z2*cos(theta);
	
% Passaggio dalla terna (x1,y1,z1) alla terna
% fissa (X,Y,Z) per rotazione di "phi" 
% attorno all'asse "Z"				
 	X =  x1*cos(phi) - y1*sin(phi);
 	Y =  x1*sin(phi) + y1*cos(phi);
 	Z =  z1;
%===============================================
	 
