%	-------------------------------------------------------------------------------
%				 TAGLIO
%	-------------------------------------------------------------------------------
%	Diagramma dell'azione di taglio su un'asta orizzontale soggetta 
%	a carichi verticali sia concentrati che distribuiti.
%	----------modalit grafica--------------
	close ; h1 = figure(1) ; 	
	set(h1, 'Units', 'normalized', 'Position', [0.5  0.5  0.5  0.5]) ; 
	hold on ; axis on  ;  grid on
	axis([0  16  -5  5]);
%	-------------- dati ---------------------------------
	xA = 2 ; 	yA = 0;	% estremo iniziale dell'asta
	xB = 12;  	yB= 0; 	% estremo finale dell'asta
	L = xB-xA; 		% lunghezza dell'asta
	q = 50 ;			% peso dell'asta (N)
	fs = 0.04; 			% fattore scala forze
	p = 0.3;			% passo per il diagramma
% 	Carichi concentrati: positivi se nel senso della normale
% 	Ff = array forze  verticali concentrate discendenti i (in newton)
 	Ff = [50 ]; 	
% 	Sf = array posizioni (in metri) delle forze  concentrate
 	Sf = [0.5*L]; 		
	nf = size(Ff,2) ; 
% 	Carico uniforme distribuito: lo consideriamo come un carico discreto
%	su un passo piccolo ottenuto dividendo "L" in "w" tronchi.
	w = 100;				% numero dei tronchi
	g = L/w;				%  g = lunghezza di ogni tronco
  	qw = q / w ; 			%  peso di ogni tronco 
	Fq =  qw * ones(1,w);  	%  array dei carichi  uniformi (N/m)
	Sq =  g/2 : g : L ;  		% array dei punti medi dei tronchi
% 	reazioni in A  e B
	risultante = sum(Ff) + sum(Fq); 	% somma delle forze
	momento = Ff * Sf' + Fq * Sq';	% somma dei momenti
	VB = momento / L ;  VA = risultante - VB ;   
%	-----------------------------------------------------------
 	for s = 0 : p : L
%		calcola la somma delle forze concentrate fino ad "s"
		Zf = Sf (Sf < s);  	% Z = array delle posizioni precedenti "s"
		zf = size(Zf,2);		% dimensioni dll'array
 		fn = 0;			% fn = somma delle forze concentrate 
		for k=1 : zf ;  fn = fn + Ff(k);   end ; 
%		aggiungi la somma delle forze distribuite fino ad "s"
		Zq = Sq (Sq < s);  	% U = array delle posizioni precedenti "s"
		zq = size(Zq,2);	% dimensioni dell'array
		for h=1 : zq ;  fn = fn + Fq(h);   end ; 
%		diagramma dell'azione di taglio "T"
		T = - VA + fn; 	% azione di taglio
		x = xA + s / L*(xB-xA); 	y = yA + s / L*(yB-yA); 
		x1 = x + nx*T*fs;  			y1 = y + ny*T*fs;  
		plot([x   x1] , [y  y1],'k','linewidth',1,'era','back')
	end
%	---------------------------------------------------------------
%	traccia asta 
	plot([xA  xB],[yA  yB],'k','linewidth',1,'era','back')
% 	traccia reazione in A
	x0 = xA ;  	y0 = yA + sign(VA) * VA* fs;  
	plot([xA   x0] , [yA  y0],'k','linewidth',2,'era','back')
% 	traccia reazione in B		
	x1 = xB ;  	y1 = yB + sign(VB) *VB* fs;  
	plot([xB   x1] , [yB  y1],'k','linewidth',2,'era','back')
% 	traccia forze  concentrate	
	for k=1 : nf
		x = xA + Sf(k)  ; 	 y = yA   ; 
		xf = x ; 			yf = y + Ff(k)*fs;  	
		plot([x  , xf] , [y , yf] ,'k','linewidth',3,'era','back')
	end
% 	traccia forze  distribuite	
	for k=1 : w
		x = xA + Sq(k)  ;  	y = yA  ; 
		xq = x ; 			yq = y + Fq(k)*fs;  	
		plot([x  , xq] , [y , yq] ,'k','linewidth',1,'era','back')
	end
%	----------------------------------------------------------- fine
