%                   interp_1
%       Dati rilevati sperimentalmente e loro
%             interpolazione lineare.
%--------------------------------------------------------
% Data una molla si rilevi la forza F necessaria
% per tenderla ad una lunghezza L. 
% Quando e' a riposo, la molla ha lunghezza L1.  
% Supposto che l'andamento F=F(L) sia di tipo lineare, 
% cioe' F=a+bL  si determinano sperimentalmente 
% alcuni valori di F corrispondenti ad assegnati valori di L.
% Siano  L(1),L(2)...L(n) ed F(1),F(2) ... F(n) 
% i valori delle lunghezze e delle forze misurate.
%
% Si osservi che abbiamo evitato di indicare con 
% L(0) la lunghezza iniziale perche' MATLAB non 
% accetta lo zero come primo indice (contatore) 
% di un vettore. L0 sarebbe accettato ma non L(0).
%
% Valori di L misurati (in cm)
	L = [2.75  4  5  7.4  9.1]; 
% valori corrispondenti di F (in N)
	F = [1.4 2.13 2.89  5.27   6.5];
%--------------------------------------------------------
% Desideriamo rappresentare tali coppie di valori
% in un diagramma cartesiano mediante crocette.
	close   % chiude finestra precedente
	h1=figure;
	whitebg('black')
  title('interpolazione lineare (...tasto)')
  axis([0 10 0 8]);
  hold on
% Traccia dei segni "+" in corrispondenza a queste coppie. 
	plot(L,F,'+')
	n = size(L,2);
	pause
%--------------------------------------------------------
% Vogliamo determinare una retta che interpoli tali valori.
% Ovvero vogliamo determinare le due costanti a e b
% della retta F=a+b*L che facciano passare "al meglio"
% la retta per i punti assegnati.
% La quantita' r=a+b*L-F, che prende il nome di residuo,
% non sara' nulla ma, per ogni coppia (L(k),F(k))
% avra' un valore r(k). 
% Ci proponiamo di determinare i valori delle 
% costanti "a" e "b" che rendono minima la somma dei
% quadrati degli errori (metodo dei minimi  quadrati o di Gauss)
% Consideriamo le quantita'		
%			r(1) = a + b*L(1) - F(1) 
%			r(2) = a + b*L(2) - F(2) 
%           ......
%			r(n) = a + b*L(n) - F(n) 
% e formiamo con esse la quantita'
%      G(a,b)=r(1)^2+r(2)^2+  .... r(n)^2
% Il minimo si realizza quando le derivate parziali
% di "G(a,b)" rispetto ad "a" e "b" sono nulle.
% Questo porta al sistema
%    SOMMA(a+ b*L(k) - F(k))      = 0 
%    SOMMA(a+ b*L(k) - F(k))*L(k) = 0 
% Posto
%		S = SOMMA L(k)    T = SOMMA L(k)^2
%		u = SOMMA F(k)    v = SOMMA [F(k)*L(k)]
	S=0; for k=1:n ; S=S+L(k) ;      end
	T=0; for k=1:n ; T=T+L(k)^2 ;    end
	u=0; for k=1:n ; u=u+F(k) ;      end
	v=0; for k=1:n ; v=v+F(k)*L(k) ; end
% il sistema diviene
%  		n a + S b = u
%  		S a + T b = v
% Fatte le posizioni   
	M=[n S ; S T]; % matrice del sistema
	b=[u v];       % vettore deei termini noti
% x = vettore incognito
% la soluzione e' data da
  x = M \ b';
% da esssa estraiamo i valori delle costanti
	a=x(1) ; b=x(2);
% La retta interpolante si  puo' tracciare ponendo
% L=0 ed L=10 e ricavando F1=a+b*0 ed F2=a+b*10
	F1= a;   F2 = a+ b*10 ;
	line([0 10], [F1  F2],'color','c','era','back');
%-----------------------------------------------







